#include <MDR32F9x.h>
#include "MDR32F9x_config.h"

void frq_init (void)
{
	MDR_RST_CLK->HS_CONTROL = 0x1;                      // Enable HSE oscillator
  while (MDR_RST_CLK->CLOCK_STATUS == 0x00) __NOP();  // wait while HSE startup
	MDR_RST_CLK->PLL_CONTROL |=(6-1)*0x100;							// PLL=6 - CPU CLK 48 MHz
	MDR_RST_CLK->PLL_CONTROL |=0x04;										// Enable PLL for CPU
	while (!(MDR_RST_CLK->CLOCK_STATUS & 0x02)) __NOP();
  MDR_RST_CLK->CPU_CLOCK = 0x106;                     // switch to HSE (8 MHz)
	SystemCoreClockUpdate();                            // Get Core Clock Frequency	
}

void SPI_init (void)
{
	//I/O ports init PF12, PF13, PF5
	MDR_RST_CLK->PER_CLOCK	|=(1<<29);									//Enable PORTF clocking
	MDR_PORTF->ANALOG				|=0xB000;										//PF12, PF13, PF15 is digital
	MDR_PORTF->OE						|=0xB000;										//PF12, PF13, PF15 is output
	//MDR_PORTD->PD						|=0x08;											//PD3 open-drain
	//MDR_PORTD->FUNC					|=0x00000000;								//PD5, PD6, PD3: CLK, MOSI and CS
	MDR_PORTF->FUNC					|=0xCC000000;								//PF13, PF15: CLK, MOSI
	MDR_PORTF->PWR					|=0xCF000000;								//PF12, PF13, PF15 is fast front
	//MDR_PORTD->RXTX					|=0x08;
	//SSP2 init
	MDR_RST_CLK->PER_CLOCK	|=(1<<20);									//Enable SSP2 clocking in PER_CLOCK
	MDR_RST_CLK->SSP_CLOCK	|=(1<<25);									//Enable SSP2 clocking in SSP_CLOCK no prescale
	MDR_RST_CLK->SSP_CLOCK	|=0x00F0;										//prescaler 4
	MDR_SSP2->CPSR					=250;												//Divider for SSP2
	MDR_SSP2->CR0						=0x0009;										//10-bit, Motorolla SPI, SPH=0, SPO=0, no-prescaller
	MDR_SSP2->CR1						=0;													//Master mode
	MDR_SSP2->CR1						|=(1<<1);										//SPI enable
}

void SPI_send (unsigned short* data, unsigned char n)
{
	unsigned char t=0;
	
	for (t=0; t<(n/2); t++)
	{
		MDR_PORTF->RXTX	&=~0x1000;
		MDR_SSP2->DR=data[2*t];
		while (MDR_SSP2->SR &0x10);
		MDR_SSP2->DR=data[2*t+1];
		while (MDR_SSP2->SR &0x10);
		MDR_PORTF->RXTX	|=0x1000;
	}
}

int main (void)
{
	unsigned int t=0;
	unsigned short data[8];
	
	frq_init();
	SPI_init();
	for (t=0; t<40000; t++);
	MDR_SSP2->DR=0;
	while (MDR_SSP2->SR &0x10);
	MDR_PORTD->RXTX |=0x02;
	while(1)
	{
		for (t=0; t<1000; t++);
		data[0]=0;
		data[1]=0;
		data[2]=(0xC8|0x0100);
		data[3]=(0x32|0x0100);
		data[4]=0x200;
		data[5]=(0x96|0x0200);
		data[6]=(0xFF|0x0300);
		data[7]=(0x64|0x0300);
		SPI_send(data, 8);	
	}
}
